
# Catálogo: Cosechando Datos Argentina

## Información General

- **Autor**: Ministerio de Modernización
- **Correo Electrónico**: datos@modernizacion.gob.ar
- **Nombre del catálogo**: Cosechando Datos Argentina
- **Descripción**:

> Datasets para reporte pre cosecha

## Estado de los metadatos y cantidad de recursos

Estado metadatos globales | Estado metadatos catálogo | # de Datasets | # de Distribuciones
--------------------------|---------------------------|---------------|--------------------
ERROR | OK | 3 | 6

## Datasets incluidos

Por favor, consulte el informe [`datasets.csv`](datasets.csv).
